@@ -34,8 +34,7 @@ class TestCMS(NereidTestCase):
         self.Website = POOL.get('nereid.website')
         self.ArticleAttribute = POOL.get('nereid.cms.article.attribute')
         self.Party = POOL.get('party.party')
-        self.MenuItem = POOL.get('nereid.cms.menuitem')
-        self.Link = POOL.get('nereid.cms.link')
+        self.Locale = POOL.get('nereid.website.locale')
 
         self.templates = {
             'home.jinja':
@@ -91,15 +90,21 @@ class TestCMS(NereidTestCase):
             'company': company.id,
         }])
 
+        # Create locale
+        en_us, = self.Language.search([('code', '=', 'en_US')])
+        self.locale_en_us, = self.Locale.create([{
+            'code': 'en_US',
+            'language': en_us.id,
+            'currency': usd.id
+        }])
         # Create website
         url_map, = self.UrlMap.search([], limit=1)
-        en_us, = self.Language.search([('code', '=', 'en_US')])
         self.Website.create([{
             'name': 'localhost',
             'url_map': url_map,
             'company': company.id,
             'application_user': USER,
-            'default_language': en_us,
+            'default_locale': self.locale_en_us.id,
             'guest_user': guest_user,
             'currencies': [('set', [usd.id])],
         }])
@@ -136,7 +141,7 @@ class TestCMS(NereidTestCase):
             self.setup_defaults()
             app = self.get_app()
             with app.test_client() as c:
-                response = c.get('/en_US/article-category/test-categ')
+                response = c.get('/article-category/test-categ')
                 self.assertEqual(response.status_code, 200)
                 self.assertEqual(response.data, '1')
 
@@ -146,7 +151,7 @@ class TestCMS(NereidTestCase):
             self.setup_defaults()
             app = self.get_app()
             with app.test_client() as c:
-                response = c.get('/en_US/article/test-article')
+                response = c.get('/article/test-article')
                 self.assertEqual(response.status_code, 200)
                 self.assertEqual(response.data, 'Test Content')
 
@@ -158,7 +163,7 @@ class TestCMS(NereidTestCase):
             self.setup_defaults()
             app = self.get_app(DEBUG=True)
             with app.test_client() as c:
-                response = c.get('/en_US/sitemaps/article-category-index.xml')
+                response = c.get('/sitemaps/article-category-index.xml')
                 self.assertEqual(response.status_code, 200)
 
     def test_0040_category_sitemap(self):
@@ -169,7 +174,7 @@ class TestCMS(NereidTestCase):
             self.setup_defaults()
             app = self.get_app()
             with app.test_client() as c:
-                response = c.get('en_US/sitemaps/article-category-1.xml')
+                response = c.get('/sitemaps/article-category-1.xml')
                 self.assertEqual(response.status_code, 200)
 
     def test_0050_article_attribute(self):
@@ -203,18 +208,6 @@ class TestCMS(NereidTestCase):
             self.Article.delete([article1])
             self.assertEqual(self.ArticleAttribute.search([], count=True), 0)
 
-    def test_0060_create_menu_item(self):
-        '''
-        Test creating a new menu item
-        '''
-        with Transaction().start(DB_NAME, USER, CONTEXT):
-            menuitem, = self.MenuItem.create([{
-                'title': 'MenuItem',
-                'unique_name': 'MenuItem',
-                'sequence': 1
-            }])
-            self.assert_(menuitem)
-
 
 def suite():
     "CMS test suite"
